@@ -1,6 +1,7 @@
 #define PY_SSIZE_T_CLEAN
 #include <Python.h>
 
+#include "python_logging.h"
 #include "qdl.h"
 
 // "%s [--debug] [--storage <emmc|ufs>] [--finalize-provisioning] [--include
@@ -20,43 +21,43 @@ static PyObject *qdl_run(PyObject *self, PyObject *args) {
   if (!PyArg_ParseTuple(args, "ssss", &storage, &mbn, &program, &patch))
     return NULL;
 
-  Py_BEGIN_ALLOW_THREADS
+  begin_allow_threads();
   type = detect_type(program);
-  Py_END_ALLOW_THREADS
+  end_allow_threads();
   if (type != QDL_FILE_PROGRAM) {
     PyErr_Format(PyExc_RuntimeError,
                  "Program passed is not a QDL program. Got type %d", type);
     return NULL;
   }
 
-  Py_BEGIN_ALLOW_THREADS
+  begin_allow_threads();
   ret = program_load(program);
-  Py_END_ALLOW_THREADS
+  end_allow_threads();
   if (ret < 0) {
     PyErr_Format(PyExc_RuntimeError, "Program load failed. Error %d", ret);
     return NULL;
   }
 
-  Py_BEGIN_ALLOW_THREADS
+  begin_allow_threads();
   type = detect_type(patch);
-  Py_END_ALLOW_THREADS
+  end_allow_threads();
   if (type != QDL_FILE_PATCH) {
     PyErr_Format(PyExc_RuntimeError,
                  "Patch passed is not a QDL patch. Got type %d", type);
     return NULL;
   }
 
-  Py_BEGIN_ALLOW_THREADS
+  begin_allow_threads();
   ret = patch_load(patch);
-  Py_END_ALLOW_THREADS
+  end_allow_threads();
   if (ret < 0) {
     PyErr_Format(PyExc_RuntimeError, "Patch load failed. Error %d", ret);
     return NULL;
   }
 
-  Py_BEGIN_ALLOW_THREADS
+  begin_allow_threads();
   libusb_init(NULL);
-  Py_END_ALLOW_THREADS
+  end_allow_threads();
   ret = find_device(&qdl);
   if (ret) {
     libusb_exit(NULL);
@@ -64,18 +65,18 @@ static PyObject *qdl_run(PyObject *self, PyObject *args) {
     return NULL;
   }
 
-  Py_BEGIN_ALLOW_THREADS
+  begin_allow_threads();
   ret = sahara_run(&qdl, mbn);
-  Py_END_ALLOW_THREADS
+  end_allow_threads();
   if (ret < 0) {
     libusb_exit(NULL);
     PyErr_Format(PyExc_RuntimeError, "Could not run Sahara. Error %d\n", ret);
     return NULL;
   }
 
-  Py_BEGIN_ALLOW_THREADS
+  begin_allow_threads();
   ret = firehose_run(&qdl, NULL, storage);
-  Py_END_ALLOW_THREADS
+  end_allow_threads();
   if (ret < 0) {
     libusb_exit(NULL);
     PyErr_Format(PyExc_RuntimeError, "Could not run Firehose. Error %d\n", ret);
